@@ -1,12 +1,9 @@
-import time
-from dataclasses import dataclass
-from typing import Optional
-import aiohttp
 import asyncio
+from dataclasses import dataclass
 
+import aiohttp
 import requests
 from requests import Response
-from requests.auth import HTTPBasicAuth
 
 
 
@@ -20,24 +17,21 @@ class Login:
 @dataclass
 class API:
     _url_prefix: str
-    _auth_token: Optional[str] = None
+    _auth_tokens: dict
 
     def _put_extra_headers(self, kwargs):
         extra_headers = kwargs.get("headers")
-        auth_values = []
-        if self._auth_token or "login" in kwargs:
+        if self._auth_tokens or "login" in kwargs:
             if extra_headers is None:
                 extra_headers = {}
                 kwargs["headers"] = extra_headers
-            if self._auth_token:
-                auth_values.append(f"Bearer {self._auth_token}")
+            for k, v in self._auth_tokens:
+                extra_headers[f"Authorization-{k}"] = f"Bearer {v}"
             if "login" in kwargs:
                 login = kwargs.pop("login")
                 # auth = HTTPBasicAuth(login.username, login.password) if login else None
                 auth = aiohttp.BasicAuth(login.username, login.password) if login else None
-                auth_values.append(auth.encode())
-            if auth_values:
-                extra_headers["Authorization"] = ",".join(auth_values)
+                extra_headers["Authorization"] = auth.encode()
     def http_get(self, path, **kwargs):
         return self.http_request("get", path, **kwargs)
 
@@ -78,9 +72,8 @@ def async_requests(reqs):
 
     async def main():
         async with aiohttp.ClientSession() as session:
-
-            async def send_request(**req):
-                async with session.request(**req) as resp:
+            async def send_request(**req_kwargs):
+                async with session.request(**req_kwargs) as resp:
                     await resp.read()
                     # noinspection PyTypeChecker
                     _default_resp_checker(obj(dict(status_code=resp.status, url=resp.url)))
@@ -147,7 +140,6 @@ def http_request(
         status_checker=_default_resp_checker,
         **kwargs
 ):
-
     resp = requests.request(method, path, json=json, data=data, params=params, headers=headers, **kwargs)
 
     if status_checker is not None:
